@@ -9,8 +9,7 @@ class FileHandler(AttrsComponent):
     log_file_name: str = DefaultSettings.log_file_name
     level: int = logging.INFO
 
-    @on(Trainer.EVENT.PREPARE)
-    def prepare_handler(self, trainer: Trainer):
+    def post_init_with_trainer(self, trainer: Trainer):
         log_file = trainer.output_dir / self.log_file_name
         self.file_handler = logging.FileHandler(str(log_file))
         self.file_handler.setLevel(self.level)
@@ -18,4 +17,5 @@ class FileHandler(AttrsComponent):
 
     @on(Trainer.EVENT.TEARDOWN)
     def remove_handler(self, trainer: Trainer):
-        logging.root.removeHandler(self.file_handler)
+        if hasattr(self, 'file_handler'):
+            logging.root.removeHandler(self.file_handler)
